package com.ruoyi.project.system.mapper;

import java.util.List;

import com.ruoyi.project.system.domain.SysIp;
import org.apache.ibatis.annotations.Select;

/**
 * 授权登录IPMapper接口
 *
 * @author ruoyi
 * @date 2023-10-16
 */
public interface SysIpMapper {
    /**
     * 查询授权登录IP
     *
     * @param id 授权登录IP主键
     * @return 授权登录IP
     */
    public SysIp selectSysIpById(Long id);

    /**
     * 查询授权登录IP列表
     *
     * @param sysIp 授权登录IP
     * @return 授权登录IP集合
     */
    public List<SysIp> selectSysIpList(SysIp sysIp);

    /**
     * 新增授权登录IP
     *
     * @param sysIp 授权登录IP
     * @return 结果
     */
    public int insertSysIp(SysIp sysIp);

    /**
     * 修改授权登录IP
     *
     * @param sysIp 授权登录IP
     * @return 结果
     */
    public int updateSysIp(SysIp sysIp);

    /**
     * 删除授权登录IP
     *
     * @param id 授权登录IP主键
     * @return 结果
     */
    public int deleteSysIpById(Long id);

    /**
     * 批量删除授权登录IP
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysIpByIds(Long[] ids);
}
